jeeves
======

Jeeves is a personal assistant similar to alexa/google, based on code from the jasper project.

Usage
-----

You must have a poopulated project first. Start with: `python -m jeeves.populate`

Run with `python -m jeeves.main`

License
-------

See included LICENSE file for more details
